@@ -1,7 +1,7 @@
 package Devel::Chitin::OpTree::PMOP;
 use base 'Devel::Chitin::OpTree::LISTOP';
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use B qw(PMf_CONTINUE PMf_ONCE PMf_GLOBAL PMf_MULTILINE PMf_KEEP PMf_SINGLELINE
          PMf_EXTENDED PMf_FOLD OPf_KIDS);
@@ -124,6 +124,35 @@ sub _match_flags {
     $flags;
 }
 
+sub _resolve_split_expr {
+    my $self = shift;
+
+    return $self->_match_op('', @_);
+}
+
+sub _resolve_split_target {
+    my $self = shift;
+
+    my $target = '';
+    if ($self->op->private & B::OPpSPLIT_ASSIGN()) {
+        if ($self->op->flags & B::OPf_STACKED()) {
+            # target is encoded as the last child op
+            $target = $self->children->[-1]->deparse;
+
+        } elsif ($self->op->private & B::OPpSPLIT_LEX()) {
+            $target = $self->_padname_sv($self->op->pmreplroot)->PV;
+
+        } else {
+            my $gv = $self->op->pmreplroot();
+            $gv = $self->_padval_sv($gv) if !ref($gv);
+            $target = '@' . $self->_gv_name($gv);
+        }
+    }
+    $target .= ' = ' if $target;
+}
+
+sub _resolve_split_target_pmop { $_[0] }
+
 1;
 
 __END__
